==> hypersnapsdk_flutter-1.0.8.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVDocsCapture.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.util.Log;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import co.hyperverge.hypersnapsdk.activities.HVDocsActivity;
import co.hyperverge.hypersnapsdk.listeners.DocCaptureCompletionHandler;
import co.hyperverge.hypersnapsdk.objects.HVDocConfig;
import co.hyperverge.hypersnapsdk.objects.HVError;
import co.hyperverge.hypersnapsdk.objects.HVResponse;


public class FLHVDocsCapture {

    static final String DOCS_CAPTURE_SET_OCR_API_DETAILS =
            "docsCaptureSetOCRAPIDetails";
    static final String DOCS_CAPTURE_SET_ASPECT_RATIO =
            "docsCaptureSetAspectRatio";
    static final String DOCS_CAPTURE_SET_SHOULD_ADD_PADDING =
            "docsCaptureSetShouldAddPadding";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_FLASH_ICON =
            "docsCaptureSetShouldShowFlashIcon";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_REVIEW_SCREEN =
            "docsCaptureSetShouldShowReviewScreen";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_SUB_TEXT =
            "docsCaptureSetDocCaptureSubText";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_DESCRIPTION =
            "docsCaptureSetDocCaptureDescription";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_INSTRUCTION_PAGE =
            "docsCaptureSetShouldShowInstructionPage";
    static final String DOCS_CAPTURE_SET_DOCUMENT_TYPE =
            "docsCaptureSetDocumentType";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_TITLE =
            "docsCaptureSetDocCaptureTitle";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_SUBTITLE =
            "docsCaptureSetDocCaptureSubtitle";
    static final String DOCS_CAPTURE_SET_DOC_REVIEW_SUBTITLE =
            "docsCaptureSetDocReviewSubtitle";
    static final String DOCS_CAPTURE_SET_DOC_REVIEW_TITLE =
            "docsCaptureSetDocReviewTitle";
    static final String DOCS_CAPTURE_SET_DOC_REVIEW_DESCRIPTION =
            "docsCaptureSetDocReviewDescription";
    static final String DOCS_CAPTURE_SET_SHOULD_ENABLE_RETRIES =
            "docsCaptureSetShouldEnableRetries";
    static final String DOCS_CAPTURE_START = "docsCaptureStart";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_CLOSE_ALERT =
            "docsCaptureSetShouldShowCloseAlert";
    static final String DOCS_CAPTURE_SET_CLOSE_ALERT_DIALOG_TITLE =
            "docsCaptureSetCloseAlertDialogTitle";
    static final String DOCS_CAPTURE_SET_CLOSE_ALERT_DIALOG_DESCRIPTION =
            "docsCaptureSetCloseAlertDialogDesc";
    static final String DOCS_CAPTURE_SET_SHOW_TRUST_LOGOS =
            "docsCaptureSetShowTrustLogos";
    static final String DOCS_CAPTURE_SET_UI_STRINGS = "docsCaptureSetUIStrings";


    private static final String DOC_CAPTURE_TITLE = "docCaptureTitle";
    private static final String DOC_CAPTURE_SUBTITLE = "docCaptureSubtitle";
    private static final String DOC_CAPTURE_DESCRIPTION = "docCaptureDescription";
    private static final String DOC_CAPTURE_SUB_TEXT = "docCaptureSubText";
    private static final String DOC_REVIEW_RETAKE_BUTTON = "docReviewRetakeButton";
    private static final String DOC_REVIEW_CONTINUE_BUTTON = "docReviewContinueButton";
    private static final String DOC_REVIEW_TITLE = "docReviewTitle";
    private static final String DOC_REVIEW_SUBTITLE = "docReviewSubtitle";
    private static final String DOC_REVIEW_DESCRIPTION = "docReviewDescription";
    private static final String DOC_RETAKE_TITLE_TEXT = "docRetakeTitleText";
    private static final String DOC_RETAKE_BUTTON_TEXT = "docRetakeButtonText";
    private static final String DOC_INSTRUCTIONS_TITLE = "docInstructionsTitle";
    private static final String DOC_INSTRUCTIONS_1 = "docInstructions1";
    private static final String DOC_INSTRUCTIONS_2 = "docInstructions2";
    private static final String DOC_INSTRUCTIONS_3 = "docInstructions3";
    private static final String DOC_INSTRUCTIONS_PROCEED = "docInstructionsProceed";

    private static final String TAG = FLHVDocsCapture.class.getSimpleName();

    private Float aspectRatio;
    private HVDocConfig docConfig;
    private boolean hasBeenCalled;

    public HVDocConfig getDocConfig() {
        if (this.docConfig == null) {
            this.docConfig = new HVDocConfig();
        }
        return this.docConfig;
    }

    public void setOCRAPIDetails(String ocrEndpoint, String documentSideString, Map<String, Object> params,
                                 Map<String, Object> headers) {
        String[] documentSideParams = documentSideString.split("\\.");
        HVDocConfig.DocumentSide documentSide = getDocumentSide(documentSideParams[2]);

        JSONObject paramsObj = new JSONObject();
        JSONObject headersObj = new JSONObject();

        try {
            if (params != null) {
                paramsObj = FLHVNetworkHelper.convertMapToJson(params);
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
        try {
            if (headers != null) {
                headersObj = FLHVNetworkHelper.convertMapToJson(headers);
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }

        if (documentSide != null) {
            getDocConfig().setOCRDetails(ocrEndpoint,
                    documentSide,
                    paramsObj.toString(),
                    headersObj.toString());
        }
    }

    private HVDocConfig.DocumentSide getDocumentSide(String documentSide) {
        switch (documentSide) {
            case "FRONT":
            case "front":
                return HVDocConfig.DocumentSide.FRONT;
            case "BACK":
            case "back":
                return HVDocConfig.DocumentSide.BACK;
            default: {
                return null;
            }
        }
    }

    public void setCustomUIStrings(String customStrings) {
        try {
            if (customStrings != null && !customStrings.trim().isEmpty()) {
                getDocConfig().setCustomUIStrings(new JSONObject(customStrings));
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
    }

    public void setUIStrings(Map<String, Object> uiStringsMap) {
        try {
            JSONObject uiStringsJsonObject = FLHVNetworkHelper.convertMapToJson(uiStringsMap);
            JSONObject customUIStrings = new JSONObject();

            // Document capture screen title
            if (uiStringsJsonObject.has(DOC_CAPTURE_TITLE)) {
                getDocConfig().setDocCaptureTitle(uiStringsJsonObject.getString(DOC_CAPTURE_TITLE));
            }

            // Document capture screen subtitle
            if (uiStringsJsonObject.has(DOC_CAPTURE_SUBTITLE)) {
                getDocConfig().setDocCaptureSubtitle(uiStringsJsonObject.getString(DOC_CAPTURE_SUBTITLE));
            }

            // Document capture screen description
            if (uiStringsJsonObject.has(DOC_CAPTURE_DESCRIPTION)) {
                getDocConfig().setDocCaptureDescription(uiStringsJsonObject.getString(DOC_CAPTURE_DESCRIPTION));
            }

            // Document capture screen sub text - FRONT/BACK text
            if (uiStringsJsonObject.has(DOC_CAPTURE_SUB_TEXT)) {
                getDocConfig().setDocCaptureSubText(uiStringsJsonObject.getString(DOC_CAPTURE_SUB_TEXT));
            }

            // Review Screen retake button
            if (uiStringsJsonObject.has(DOC_REVIEW_RETAKE_BUTTON)) {
                customUIStrings.put(DOC_REVIEW_RETAKE_BUTTON, uiStringsJsonObject.getString(
                        DOC_REVIEW_RETAKE_BUTTON));
            }

            // Review Screen continue button
            if (uiStringsJsonObject.has(DOC_REVIEW_CONTINUE_BUTTON)) {
                customUIStrings.put(DOC_REVIEW_CONTINUE_BUTTON, uiStringsJsonObject.getString(
                        DOC_REVIEW_CONTINUE_BUTTON));
            }

            // Instructions Page Title
            if (uiStringsJsonObject.has(DOC_INSTRUCTIONS_TITLE)) {
                customUIStrings.put(DOC_INSTRUCTIONS_TITLE, uiStringsJsonObject.getString(
                        DOC_INSTRUCTIONS_TITLE));
            }

            // Instructions 1
            if (uiStringsJsonObject.has(DOC_INSTRUCTIONS_1)) {
                customUIStrings.put(DOC_INSTRUCTIONS_1, uiStringsJsonObject.getString(
                        DOC_INSTRUCTIONS_1));
            }

            // Instructions 2
            if (uiStringsJsonObject.has(DOC_INSTRUCTIONS_2)) {
                customUIStrings.put(DOC_INSTRUCTIONS_2, uiStringsJsonObject.getString(
                        DOC_INSTRUCTIONS_2));
            }

            // Instructions 3
            if (uiStringsJsonObject.has(DOC_INSTRUCTIONS_3)) {
                customUIStrings.put(DOC_INSTRUCTIONS_3, uiStringsJsonObject.getString(
                        DOC_INSTRUCTIONS_3));
            }

            // Instructions Proceed
            if (uiStringsJsonObject.has(DOC_INSTRUCTIONS_PROCEED)) {
                customUIStrings.put(DOC_INSTRUCTIONS_PROCEED, uiStringsJsonObject.getString(
                        DOC_INSTRUCTIONS_PROCEED));
            }

            // Review Screen title
            if (uiStringsJsonObject.has(DOC_REVIEW_TITLE)) {
                getDocConfig().setDocReviewTitle(uiStringsJsonObject.getString(DOC_REVIEW_TITLE));
            }

            // Review Screen subtitle
            if (uiStringsJsonObject.has(DOC_REVIEW_SUBTITLE)) {
                getDocConfig().setDocReviewSubtitle(uiStringsJsonObject.getString(DOC_REVIEW_SUBTITLE));
            }

            // Review Screen description
            if (uiStringsJsonObject.has(DOC_REVIEW_DESCRIPTION)) {
                getDocConfig().setDocReviewDescription(uiStringsJsonObject.getString(DOC_REVIEW_DESCRIPTION));
            }

            if (uiStringsJsonObject.has(DOC_RETAKE_TITLE_TEXT)) {
                getDocConfig().setErrorReviewTitle(uiStringsJsonObject.getString(DOC_RETAKE_TITLE_TEXT));
            }

            if (uiStringsJsonObject.has(DOC_RETAKE_BUTTON_TEXT)) {
                getDocConfig().setErrorReviewRetakeButton(uiStringsJsonObject.getString(DOC_RETAKE_BUTTON_TEXT));
            }

            // Using customUIStrings
            getDocConfig().setCustomUIStrings(customUIStrings);

        } catch (JSONException e) {
            Log.e(TAG, e.getMessage());
        }
    }


    public void setAspectRatio(Float aspectRatioValue) {
        aspectRatio = aspectRatioValue;
    }


    public void setShouldAddPadding(Boolean shouldSetPadding) {
        getDocConfig().setShouldAddPadding(shouldSetPadding);

    }


    public void setPadding(Number padding) {
        getDocConfig().setPadding((float) padding);

    }


    public void setShouldShowFlashIcon(Boolean shouldShowFlashIcon) {
        getDocConfig().setShouldShowFlashIcon(shouldShowFlashIcon);
    }


    public void setShouldShowReviewScreen(Boolean shouldShowReviewScreen) {
        getDocConfig().setShouldShowReviewScreen(shouldShowReviewScreen);
    }


    public void setDocCaptureSubText(String subText) {
        getDocConfig().setDocCaptureSubText(subText);
    }


    public void setDocCaptureDescription(String description) {
        getDocConfig().setDocCaptureDescription(description);
    }


    public void setShouldShowInstructionPage(Boolean shouldShowInstructionPage) {
        getDocConfig().setShouldShowInstructionPage(shouldShowInstructionPage);
    }

    public void setShouldEnableRetries(boolean shouldEnableRetries) {
        getDocConfig().setShouldEnableRetries(shouldEnableRetries);
    }

    public HVDocConfig getConfig() {
        return getDocConfig();
    }


    public void setDocumentType(String docTypeValue) {
        try {
            String docType = docTypeValue.split("\\.")[1];
            if (docType == null) {
                docType = "Card";
            }

            HVDocConfig.Document doc = HVDocConfig.Document.valueOf(docType);
            if (aspectRatio != null)
                doc.setAspectRatio(this.aspectRatio);

            getDocConfig().setDocumentType(doc);
        } catch (Exception exp) {
            Log.e(TAG, exp.getMessage());
        }
    }


    public void setDocCaptureTitle(String titleText) {
        getDocConfig().setDocCaptureTitle(titleText);
    }

    public void setDocCaptureSubTitle(String subTitleText) {
        getDocConfig().setDocCaptureSubtitle(subTitleText);
    }

    public void setDocReviewTitle(String docReviewTitle) {
        getDocConfig().setDocReviewTitle(docReviewTitle);
    }

    public void setDocReviewSubTitle(String docReviewSubTitle) {
        getDocConfig().setDocReviewSubtitle(docReviewSubTitle);
    }

    public void setDocReviewDescription(String docReviewDescription) {
        getDocConfig().setDocReviewDescription(docReviewDescription);
    }

    public void setShouldShowCloseAlert(boolean shouldShowCloseAlert) {
        getDocConfig().setShouldShowCloseAlert(shouldShowCloseAlert);
    }

    public void setCloseAlertDialogTitle(String closeAlertDialogTitle) {
        getDocConfig().setCloseAlertDialogTitle(closeAlertDialogTitle);
    }

    public void setCloseAlertDialogDescription(String closeAlertDialogDescription) {
        getDocConfig().setCloseAlertDialogDesc(closeAlertDialogDescription);
    }

    public void setShouldShowTrustLogos(boolean shouldShowTrustLogos) {
        getDocConfig().setShowTrustLogos(shouldShowTrustLogos);
    }

    public void start(Context context, final DocCaptureCompletionHandler callback) {
        hasBeenCalled = false;


        HVDocsActivity.start(context, getDocConfig(), new DocCaptureCompletionHandler() {
            @Override
            public void onResult(HVError error, HVResponse hvResponse) {
                callback.onResult(error, hvResponse);
            }
        });
    }

    public List<Map<String, Object>> getMapsFromOnResult(HVError error, HVResponse hvResponse) {
        ArrayList<Map<String, Object>> arrayList = new ArrayList<>();
        Map<String, Object> errorObj = new HashMap<>();
        Map<String, Object> resultObj = new HashMap<>();

        try {

            if (error != null) {
                errorObj.put("errorCode", error.getErrorCode());
                errorObj.put("errorMessage", error.getErrorMessage());
                if (!hasBeenCalled) {
                    hasBeenCalled = true;
                }
            } else {
                JSONObject result = hvResponse.getApiResult();
                JSONObject headers = hvResponse.getApiHeaders();

                String imageURI = hvResponse.getImageURI();
                String fullImageUri = hvResponse.getFullImageURI();
                String action = hvResponse.getAction();
                String retakeMessage = hvResponse.getRetakeMessage();
                String videoUri = hvResponse.getVideoUri();

                if (result != null) {
                    resultObj = FLHVNetworkHelper.convertJsonToMap(result);
                    resultObj.put("apiResult", result.toString());
                    resultObj.put("imageUri", imageURI);
                    resultObj.put("videoUri", videoUri);
                    if (fullImageUri != null && !fullImageUri.isEmpty()) {
                        resultObj.put("fullImageUri", fullImageUri);
                    }
                    if (retakeMessage != null && !retakeMessage.isEmpty()) {
                        resultObj.put("retakeMessage", retakeMessage);
                    }
                    if (action != null && !action.isEmpty()) {
                        resultObj.put("action", action);
                    }
                }
                if (headers != null) {
                    resultObj.put("apiHeaders", headers.toString());
                }
                if (!hasBeenCalled) {
                    hasBeenCalled = true;
                }
            }
        } catch (Exception e) {
            Log.e(TAG, (e.getMessage()));
        }
        arrayList.add(errorObj);
        arrayList.add(resultObj);
        return arrayList;
    }


}

==> hypersnapsdk_flutter-1.1.4.tar.gz: android/src/main/java/co/hyperverge/hypersnapsdk/hypersnapsdk_flutter/FLHVDocsCapture.java <==
package co.hyperverge.hypersnapsdk.hypersnapsdk_flutter;

import android.content.Context;
import android.util.Log;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import co.hyperverge.hypersnapsdk.activities.HVDocsActivity;
import co.hyperverge.hypersnapsdk.listeners.DocCaptureCompletionHandler;
import co.hyperverge.hypersnapsdk.objects.HVDocConfig;
import co.hyperverge.hypersnapsdk.objects.HVError;
import co.hyperverge.hypersnapsdk.objects.HVResponse;


public class FLHVDocsCapture {

    static final String DOCS_CAPTURE_SET_OCR_API_DETAILS =
            "docsCaptureSetOCRAPIDetails";
    static final String DOCS_CAPTURE_SET_ASPECT_RATIO =
            "docsCaptureSetAspectRatio";
    static final String DOCS_CAPTURE_SET_SHOULD_ADD_PADDING =
            "docsCaptureSetShouldAddPadding";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_FLASH_ICON =
            "docsCaptureSetShouldShowFlashIcon";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_REVIEW_SCREEN =
            "docsCaptureSetShouldShowReviewScreen";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_SUB_TEXT =
            "docsCaptureSetDocCaptureSubText";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_DESCRIPTION =
            "docsCaptureSetDocCaptureDescription";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_INSTRUCTION_PAGE =
            "docsCaptureSetShouldShowInstructionPage";
    static final String DOCS_CAPTURE_SET_DOCUMENT_TYPE =
            "docsCaptureSetDocumentType";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_TITLE =
            "docsCaptureSetDocCaptureTitle";
    static final String DOCS_CAPTURE_SET_DOC_CAPTURE_SUBTITLE =
            "docsCaptureSetDocCaptureSubtitle";
    static final String DOCS_CAPTURE_SET_DOC_REVIEW_SUBTITLE =
            "docsCaptureSetDocReviewSubtitle";
    static final String DOCS_CAPTURE_SET_DOC_REVIEW_TITLE =
            "docsCaptureSetDocReviewTitle";
    static final String DOCS_CAPTURE_SET_DOC_REVIEW_DESCRIPTION =
            "docsCaptureSetDocReviewDescription";
    static final String DOCS_CAPTURE_SET_SHOULD_ENABLE_RETRIES =
            "docsCaptureSetShouldEnableRetries";
    static final String DOCS_CAPTURE_START = "docsCaptureStart";
    static final String DOCS_CAPTURE_SET_SHOULD_SHOW_CLOSE_ALERT =
            "docsCaptureSetShouldShowCloseAlert";
    static final String DOCS_CAPTURE_SET_CLOSE_ALERT_DIALOG_TITLE =
            "docsCaptureSetCloseAlertDialogTitle";
    static final String DOCS_CAPTURE_SET_CLOSE_ALERT_DIALOG_DESCRIPTION =
            "docsCaptureSetCloseAlertDialogDesc";
    static final String DOCS_CAPTURE_SET_SHOW_TRUST_LOGOS =
            "docsCaptureSetShowTrustLogos";
    static final String DOCS_CAPTURE_SET_UI_STRINGS = "docsCaptureSetUIStrings";

    private static final String TAG = FLHVDocsCapture.class.getSimpleName();

    private Float aspectRatio;
    private HVDocConfig docConfig;
    private boolean hasBeenCalled;

    public HVDocConfig getDocConfig() {
        if (this.docConfig == null) {
            this.docConfig = new HVDocConfig();
        }
        return this.docConfig;
    }

    public void setOCRAPIDetails(String ocrEndpoint, String documentSideString, Map<String, Object> params,
                                 Map<String, Object> headers) {
        String[] documentSideParams = documentSideString.split("\\.");
        HVDocConfig.DocumentSide documentSide = getDocumentSide(documentSideParams[2]);

        JSONObject paramsObj = new JSONObject();
        JSONObject headersObj = new JSONObject();

        try {
            if (params != null) {
                paramsObj = FLHVNetworkHelper.convertMapToJson(params);
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
        try {
            if (headers != null) {
                headersObj = FLHVNetworkHelper.convertMapToJson(headers);
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }

        if (documentSide != null) {
            getDocConfig().setOCRDetails(ocrEndpoint,
                    documentSide,
                    paramsObj.toString(),
                    headersObj.toString());
        }
    }

    private HVDocConfig.DocumentSide getDocumentSide(String documentSide) {
        switch (documentSide) {
            case "FRONT":
            case "front":
                return HVDocConfig.DocumentSide.FRONT;
            case "BACK":
            case "back":
                return HVDocConfig.DocumentSide.BACK;
            default: {
                return null;
            }
        }
    }

    public void setCustomUIStrings(String customStrings) {
        try {
            if (customStrings != null && !customStrings.trim().isEmpty()) {
                getDocConfig().setCustomUIStrings(new JSONObject(customStrings));
            }
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
    }

    public void setUIStrings(Map<String, Object> uiStringsMap) {
        try {
            JSONObject uiStringsJsonObject = FLHVNetworkHelper.convertMapToJson(uiStringsMap);
            // Using customUIStrings
            getDocConfig().setCustomUIStrings(uiStringsJsonObject);
        } catch (JSONException e) {
            Log.e(TAG, e.getMessage());
        }
    }


    public void setAspectRatio(Float aspectRatioValue) {
        aspectRatio = aspectRatioValue;
    }


    public void setShouldAddPadding(Boolean shouldSetPadding) {
        getDocConfig().setShouldAddPadding(shouldSetPadding);

    }


    public void setPadding(Number padding) {
        getDocConfig().setPadding((float) padding);

    }


    public void setShouldShowFlashIcon(Boolean shouldShowFlashIcon) {
        getDocConfig().setShouldShowFlashIcon(shouldShowFlashIcon);
    }


    public void setShouldShowReviewScreen(Boolean shouldShowReviewScreen) {
        getDocConfig().setShouldShowReviewScreen(shouldShowReviewScreen);
    }


    public void setDocCaptureSubText(String subText) {
        getDocConfig().setDocCaptureSubText(subText);
    }


    public void setDocCaptureDescription(String description) {
        getDocConfig().setDocCaptureDescription(description);
    }


    public void setShouldShowInstructionPage(Boolean shouldShowInstructionPage) {
        getDocConfig().setShouldShowInstructionPage(shouldShowInstructionPage);
    }

    public void setShouldEnableRetries(boolean shouldEnableRetries) {
        getDocConfig().setShouldEnableRetries(shouldEnableRetries);
    }

    public HVDocConfig getConfig() {
        return getDocConfig();
    }


    public void setDocumentType(String docTypeValue) {
        try {
            String docType = docTypeValue.split("\\.")[1];
            if (docType == null) {
                docType = "Card";
            }

            HVDocConfig.Document doc = HVDocConfig.Document.valueOf(docType);
            if (aspectRatio != null)
                doc.setAspectRatio(this.aspectRatio);

            getDocConfig().setDocumentType(doc);
        } catch (Exception exp) {
            Log.e(TAG, exp.getMessage());
        }
    }


    public void setDocCaptureTitle(String titleText) {
        getDocConfig().setDocCaptureTitle(titleText);
    }

    public void setDocCaptureSubTitle(String subTitleText) {
        getDocConfig().setDocCaptureSubtitle(subTitleText);
    }

    public void setDocReviewTitle(String docReviewTitle) {
        getDocConfig().setDocReviewTitle(docReviewTitle);
    }

    public void setDocReviewSubTitle(String docReviewSubTitle) {
        getDocConfig().setDocReviewSubtitle(docReviewSubTitle);
    }

    public void setDocReviewDescription(String docReviewDescription) {
        getDocConfig().setDocReviewDescription(docReviewDescription);
    }

    public void setShouldShowCloseAlert(boolean shouldShowCloseAlert) {
        getDocConfig().setShouldShowCloseAlert(shouldShowCloseAlert);
    }

    public void setCloseAlertDialogTitle(String closeAlertDialogTitle) {
        getDocConfig().setCloseAlertDialogTitle(closeAlertDialogTitle);
    }

    public void setCloseAlertDialogDescription(String closeAlertDialogDescription) {
        getDocConfig().setCloseAlertDialogDesc(closeAlertDialogDescription);
    }

    public void setShouldShowTrustLogos(boolean shouldShowTrustLogos) {
        getDocConfig().setShowTrustLogos(shouldShowTrustLogos);
    }

    public void start(Context context, final DocCaptureCompletionHandler callback) {
        hasBeenCalled = false;


        HVDocsActivity.start(context, getDocConfig(), new DocCaptureCompletionHandler() {
            @Override
            public void onResult(HVError error, HVResponse hvResponse) {
                callback.onResult(error, hvResponse);
            }
        });
    }

    public List<Map<String, Object>> getMapsFromOnResult(HVError error, HVResponse hvResponse) {
        ArrayList<Map<String, Object>> arrayList = new ArrayList<>();
        Map<String, Object> errorObj = new HashMap<>();
        Map<String, Object> resultObj = new HashMap<>();

        try {
            if (error != null) {
                errorObj.put("errorCode", error.getErrorCode());
                errorObj.put("errorMessage", error.getErrorMessage());
                if (!hasBeenCalled) {
                    hasBeenCalled = true;
                }
            }
            if (hvResponse != null) {
                JSONObject result = hvResponse.getApiResult();
                JSONObject headers = hvResponse.getApiHeaders();

                String imageURI = hvResponse.getImageURI();
                String fullImageUri = hvResponse.getFullImageURI();
                String action = hvResponse.getAction();
                String retakeMessage = hvResponse.getRetakeMessage();
                String videoUri = hvResponse.getVideoUri();

                if (result != null) {
                    resultObj = FLHVNetworkHelper.convertJsonToMap(result);
                    resultObj.put("apiResult", result.toString());
                    resultObj.put("imageUri", imageURI);
                    if (videoUri != null && !videoUri.isEmpty()) {
                        resultObj.put("videoUri", videoUri);
                    }
                    if (fullImageUri != null && !fullImageUri.isEmpty()) {
                        resultObj.put("fullImageUri", fullImageUri);
                    }
                    if (retakeMessage != null && !retakeMessage.isEmpty()) {
                        resultObj.put("retakeMessage", retakeMessage);
                    }
                    if (action != null && !action.isEmpty()) {
                        resultObj.put("action", action);
                    }
                }
                if (headers != null) {
                    resultObj.put("apiHeaders", headers.toString());
                }
                if (!hasBeenCalled) {
                    hasBeenCalled = true;
                }
            }
        } catch (Exception e) {
            Log.e(TAG, (e.getMessage()));
        }
        arrayList.add(errorObj);
        arrayList.add(resultObj);
        return arrayList;
    }
}
